@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -43,12 +43,14 @@ static gboolean    sync_gconf( GConfClient *gconf, gchar **message );
 
 /**
  * na_gconf_utils_get_subdirs:
- * @gconf: a  #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: a full path to be readen.
  *
  * Returns: a list of full path subdirectories.
  *
- * The returned list should be #na_gconf_utils_free_subdirs() by the caller.
+ * The returned list should be na_gconf_utils_free_subdirs() by the caller.
+ *
+ * Since: 2.30
  */
 GSList *
 na_gconf_utils_get_subdirs( GConfClient *gconf, const gchar *path )
@@ -70,9 +72,11 @@ na_gconf_utils_get_subdirs( GConfClient *gconf, const gchar *path )
 
 /**
  * na_gconf_utils_free_subdirs:
- * @subdirs: the subdirectory list as returned from #na_gconf_utils_get_subdirs().
+ * @subdirs: the subdirectory list as returned from na_gconf_utils_get_subdirs().
  *
  * Release the list.
+ *
+ * Since: 2.30
  */
 void
 na_gconf_utils_free_subdirs( GSList *subdirs )
@@ -82,11 +86,13 @@ na_gconf_utils_free_subdirs( GSList *subdirs )
 
 /**
  * na_gconf_utils_has_entry:
- * @entries: the list of entries as returned by #na_gconf_utils_get_entries().
+ * @entries: the list of entries as returned by na_gconf_utils_get_entries().
  * @entry: the entry to be tested.
  *
  * Returns: %TRUE if the given @entry exists in the specified @entries,
  * %FALSE else.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
@@ -107,7 +113,7 @@ na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
 
 /**
  * na_gconf_utils_get_entries:
- * @gconf: a  #GConfClient instance.
+ * @gconf: a  GConfClient instance.
  * @path: a full path to be readen.
  *
  * Loads all the key=value pairs of the specified key.
@@ -117,6 +123,8 @@ na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
  * The returned list is not recursive : it contains only the immediate
  * children of @path. To free the returned list, call
  * na_gconf_utils_free_entries().
+ *
+ * Since: 2.30
  */
 GSList *
 na_gconf_utils_get_entries( GConfClient *gconf, const gchar *path )
@@ -146,6 +154,8 @@ na_gconf_utils_get_entries( GConfClient *gconf, const gchar *path )
  *
  * If the entry was not found, or was not of boolean type, @value is set
  * to %FALSE.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_get_bool_from_entries( GSList *entries, const gchar *entry, gboolean *value )
@@ -193,6 +203,8 @@ na_gconf_utils_get_bool_from_entries( GSList *entries, const gchar *entry, gbool
  * to %NULL.
  *
  * If @value is returned not NULL, it should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_get_string_from_entries( GSList *entries, const gchar *entry, gchar **value )
@@ -239,8 +251,10 @@ na_gconf_utils_get_string_from_entries( GSList *entries, const gchar *entry, gch
  * If the entry was not found, or was not of string list type, @value
  * is set to %NULL.
  *
- * If @value is returned not NULL, it should be na_utils_free_string_list()
+ * If @value is returned not NULL, it should be na_core_utils_slist_free()
  * by the caller.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_get_string_list_from_entries( GSList *entries, const gchar *entry, GSList **value )
@@ -282,80 +296,90 @@ na_gconf_utils_get_string_list_from_entries( GSList *entries, const gchar *entry
 
 /**
  * na_gconf_utils_dump_entries:
- * @list: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
+ * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
  *
  * Dumps the content of the entries.
+ *
+ * Since: 2.30
  */
 void
-na_gconf_utils_dump_entries( GSList *list )
+na_gconf_utils_dump_entries( GSList *entries )
 {
-	g_slist_foreach( list, ( GFunc ) dump_entry, NULL );
+	g_slist_foreach( entries, ( GFunc ) dump_entry, NULL );
 }
 
 static void
 dump_entry( GConfEntry *entry, void *user_data )
 {
 	static const gchar *thisfn = "na_gconf_utils_dump_entry";
+	gchar *str = NULL;
+	gboolean str_free = FALSE;
 
 	gchar *key = g_path_get_basename( gconf_entry_get_key( entry ));
 	GConfValue *value = gconf_entry_get_value( entry );
-	gchar *str;
-	gboolean str_free = FALSE;
 
-	switch( value->type ){
-		case GCONF_VALUE_STRING:
-			str = ( gchar * ) gconf_value_get_string( value );
-			break;
+	if( value ){
+		switch( value->type ){
+			case GCONF_VALUE_STRING:
+				str = ( gchar * ) gconf_value_get_string( value );
+				break;
 
-		case GCONF_VALUE_INT:
-			str = g_strdup_printf( "%d", gconf_value_get_int( value ));
-			str_free = TRUE;
-			break;
+			case GCONF_VALUE_INT:
+				str = g_strdup_printf( "%d", gconf_value_get_int( value ));
+				str_free = TRUE;
+				break;
 
-		case GCONF_VALUE_FLOAT:
-			str = g_strdup_printf( "%f", gconf_value_get_float( value ));
-			str_free = TRUE;
-			break;
+			case GCONF_VALUE_FLOAT:
+				str = g_strdup_printf( "%f", gconf_value_get_float( value ));
+				str_free = TRUE;
+				break;
 
-		case GCONF_VALUE_BOOL:
-			str = g_strdup_printf( "%s", gconf_value_get_bool( value ) ? "True":"False" );
-			str_free = TRUE;
-			break;
+			case GCONF_VALUE_BOOL:
+				str = g_strdup_printf( "%s", gconf_value_get_bool( value ) ? "True":"False" );
+				str_free = TRUE;
+				break;
 
-		default:
-			str = g_strdup( "(undetermined value)" );
-			str_free = TRUE;
+			default:
+				str = g_strdup( "(undetermined value)" );
+				str_free = TRUE;
+		}
 	}
+
 	g_debug( "%s: key=%s, value=%s", thisfn, key, str );
 
 	if( str_free ){
 		g_free( str );
 	}
+
 	g_free( key );
 }
 
 /**
  * na_gconf_utils_free_entries:
- * @list: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
+ * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
  *
  * Releases the provided list.
+ *
+ * Since: 2.30
  */
 void
-na_gconf_utils_free_entries( GSList *list )
+na_gconf_utils_free_entries( GSList *entries )
 {
-	g_slist_foreach( list, ( GFunc ) gconf_entry_unref, NULL );
-	g_slist_free( list );
+	g_slist_foreach( entries, ( GFunc ) gconf_entry_unref, NULL );
+	g_slist_free( entries );
 }
 
 /**
  * na_gconf_utils_read_bool:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @use_schema: whether to use the default value from schema, or not.
  * @default_value: default value to be used if schema is not used or
  * doesn't exist.
  *
  * Returns: the required boolean value.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_read_bool( GConfClient *gconf, const gchar *path, gboolean use_schema, gboolean default_value )
@@ -378,13 +402,15 @@ na_gconf_utils_read_bool( GConfClient *gconf, const gchar *path, gboolean use_sc
 
 /**
  * na_gconf_utils_read_int:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @use_schema: whether to use the default value from schema, or not.
  * @default_value: default value to be used if schema is not used or
  * doesn't exist.
  *
  * Returns: the required integer value.
+ *
+ * Since: 2.30
  */
 gint
 na_gconf_utils_read_int( GConfClient *gconf, const gchar *path, gboolean use_schema, gint default_value )
@@ -408,7 +434,7 @@ na_gconf_utils_read_int( GConfClient *gconf, const gchar *path, gboolean use_sch
 
 /**
  * na_gconf_utils_read_string:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @use_schema: whether to use the default value from schema, or not.
  * @default_value: default value to be used if schema is not used or
@@ -416,6 +442,8 @@ na_gconf_utils_read_int( GConfClient *gconf, const gchar *path, gboolean use_sch
  *
  * Returns: the required string value in a newly allocated string which
  * should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_gconf_utils_read_string( GConfClient *gconf, const gchar *path, gboolean use_schema, const gchar *default_value )
@@ -440,13 +468,15 @@ na_gconf_utils_read_string( GConfClient *gconf, const gchar *path, gboolean use_
 
 /**
  * na_gconf_utils_read_string_list:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the key to be read.
  *
  * Returns: a list of strings,
  * or %NULL if the entry was not found or was not of string list type.
  *
- * The returned list must be released with na_utils_free_string_list().
+ * The returned list must be released with na_core_utils_slist_free().
+ *
+ * Since: 2.30
  */
 GSList *
 na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
@@ -470,7 +500,7 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
 
 /**
  * na_gconf_utils_write_bool:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @value: the value to be written.
  * @message: a pointer to a gchar * which will be allocated if needed.
@@ -481,6 +511,8 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value, gchar **message )
@@ -505,7 +537,7 @@ na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value
 
 /**
  * na_gconf_utils_write_int:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @value: the value to be written.
  * @message: a pointer to a gchar * which will be allocated if needed.
@@ -516,6 +548,8 @@ na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gchar **message )
@@ -540,7 +574,7 @@ na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gch
 
 /**
  * na_gconf_utils_write_string:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @value: the value to be written.
  * @message: a pointer to a gchar * which will be allocated if needed.
@@ -551,6 +585,8 @@ na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gch
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar *value, gchar **message )
@@ -575,7 +611,7 @@ na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar
 
 /**
  * na_gconf_utils_write_string_list:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @value: the list of values to be written.
  * @message: a pointer to a gchar * which will be allocated if needed.
@@ -586,6 +622,8 @@ na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList *value, gchar **message )
@@ -615,11 +653,15 @@ na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList
 
 /**
  * na_gconf_utils_remove_entry:
- * @gconf: a #GConfClient instance.
+ * @gconf: a GConfClient instance.
  * @path: the full path to the entry.
  * @message: a pointer to a gchar * which will be allocated if needed.
  *
  * Removes an entry from user preferences.
+ *
+ * Returns: %TRUE if the operation was successfull, %FALSE else.
+ *
+ * Since: 2.30
  */
 gboolean
 na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **message )
@@ -656,6 +698,8 @@ na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **mess
  * Returns: a newly allocated list of strings, which should be
  * na_core_utils_slist_free() by the caller, or %NULL if the provided
  * string was not of the GConf form.
+ *
+ * Since: 2.30
  */
 GSList *
 na_gconf_utils_slist_from_string( const gchar *value )
@@ -689,6 +733,8 @@ na_gconf_utils_slist_from_string( const gchar *value )
  *
  * Returns: the content of @slist, with the GConf format, as a newly
  * allocated string which should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_gconf_utils_slist_to_string( GSList *slist )
