@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -38,7 +38,7 @@
 
 /* private interface data
  */
-struct NAIAboutInterfacePrivate {
+struct _NAIAboutInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
@@ -141,7 +141,7 @@ v_get_toplevel( NAIAbout *instance )
 	return( NULL );
 }
 
-/**
+/*
  * na_iabout_display:
  * @instance: the #NAIAbout implementor.
  *
@@ -173,16 +173,16 @@ na_iabout_display( NAIAbout *instance )
 	};
 
 	static gchar *license[] = {
-		N_( "Nautilus Actions Configuration Tool is free software; you can "
+		N_( "Nautilus-Actions Configuration Tool is free software; you can "
 			"redistribute it and/or modify it under the terms of the GNU General "
 			"Public License as published by the Free Software Foundation; either "
 			"version 2 of the License, or (at your option) any later version." ),
-		N_( "Nautilus Actions Configuration Tool is distributed in the hope that it "
+		N_( "Nautilus-Actions Configuration Tool is distributed in the hope that it "
 			"will be useful, but WITHOUT ANY WARRANTY; without even the implied "
 			"warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See "
 			"the GNU General Public License for more details." ),
 		N_( "You should have received a copy of the GNU General Public License along "
-			"with Nautilus Actions Configuration Tool ; if not, write to the Free "
+			"with Nautilus-Actions Configuration Tool ; if not, write to the Free "
 			"Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, "
 			"MA 02110-1301, USA." ),
 		NULL
@@ -203,6 +203,8 @@ na_iabout_display( NAIAbout *instance )
 		gtk_show_about_dialog( toplevel,
 				"artists", artists,
 				"authors", authors,
+				/* i10n: "Nautilus actions" here is not a typo; this does not refer to the
+				 * Nautilus-Actions product, but to the actions which are to be added to Nautilus */
 				"comments", _( "A graphical interface to create and edit your Nautilus actions." ),
 				"copyright", copyright,
 				"documenters", documenters,
@@ -222,7 +224,7 @@ na_iabout_display( NAIAbout *instance )
 	}
 }
 
-/**
+/*
  * na_iabout_get_icon_name:
  *
  * Returns: the name of the default icon for the application, as a newly
@@ -234,7 +236,7 @@ na_iabout_get_icon_name( void )
 	return( g_strdup( PACKAGE ));
 }
 
-/**
+/*
  * na_iabout_get_copyright:
  * @console: whether the string is to be printed on a console.
  *
@@ -252,7 +254,7 @@ na_iabout_get_copyright( gboolean console )
 	copyright = g_strdup_printf(
 			_( "Copyright %s 2005 The GNOME Foundation\n"
 				"Copyright %s 2006, 2007, 2008 Frederic Ruaudel <grumz@grumz.net>\n"
-				"Copyright %s 2009, 2010 Pierre Wieser <pwieser@trychlos.org>" ), symbol, symbol, symbol );
+				"Copyright %s 2009, 2010, 2011 Pierre Wieser <pwieser@trychlos.org>" ), symbol, symbol, symbol );
 
 	g_free( symbol );
 
