@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -649,7 +649,7 @@ parse_parameters( NactICommandTab *instance )
 	gchar *exec, *returned;
 
 	exec = g_strdup_printf( "%s %s", command, param_template );
-	returned = na_tokens_parse_parameters( st_tokens, exec, FALSE );
+	returned = na_tokens_parse_for_display( st_tokens, exec, FALSE );
 	g_free( exec );
 
 	return( returned );
